==> eqxvision-0.1.8.tar.gz: eqxvision-0.1.8/eqxvision/models/__init__.py <==
from .classification.alexnet import AlexNet, alexnet
from .classification.convnext import (
    ConvNeXt,
    convnext_base,
    convnext_large,
    convnext_small,
    convnext_tiny,
)
from .classification.densenet import (
    DenseNet,
    densenet121,
    densenet161,
    densenet169,
    densenet201,
)
from .classification.efficientnet import (
    EfficientNet,
    efficientnet_b0,
    efficientnet_b1,
    efficientnet_b2,
    efficientnet_b3,
    efficientnet_b4,
    efficientnet_b5,
    efficientnet_b6,
    efficientnet_b7,
    efficientnet_v2_l,
    efficientnet_v2_m,
    efficientnet_v2_s,
)
from .classification.googlenet import GoogLeNet, googlenet
from .classification.mobilenetv2 import mobilenet_v2, MobileNetV2
from .classification.mobilenetv3 import (
    mobilenet_v3_large,
    mobilenet_v3_small,
    MobileNetV3,
)
from .classification.resnet import (
    ResNet,
    resnet18,
    resnet34,
    resnet50,
    resnet101,
    resnet152,
    resnext50_32x4d,
    resnext101_32x8d,
    wide_resnet50_2,
    wide_resnet101_2,
)
from .classification.shufflenetv2 import (
    shufflenet_v2_x0_5,
    shufflenet_v2_x1_0,
    shufflenet_v2_x1_5,
    shufflenet_v2_x2_0,
    ShuffleNetV2,
)
from .classification.squeezenet import SqueezeNet, squeezenet1_0, squeezenet1_1
from .classification.vgg import (
    VGG,
    vgg11,
    vgg11_bn,
    vgg13,
    vgg13_bn,
    vgg16,
    vgg16_bn,
    vgg19,
    vgg19_bn,
)
from .classification.vit import (
    VisionTransformer,
    vit_base,
    vit_small,
    vit_tiny,
    VitAttention,
    VitBlock,
)

==> eqxvision-0.1.11.tar.gz: eqxvision-0.1.11/eqxvision/models/__init__.py <==
from .classification.alexnet import AlexNet, alexnet
from .classification.convnext import (
    ConvNeXt,
    convnext_base,
    convnext_large,
    convnext_small,
    convnext_tiny,
)
from .classification.densenet import (
    DenseNet,
    densenet121,
    densenet161,
    densenet169,
    densenet201,
)
from .classification.efficientnet import (
    EfficientNet,
    efficientnet_b0,
    efficientnet_b1,
    efficientnet_b2,
    efficientnet_b3,
    efficientnet_b4,
    efficientnet_b5,
    efficientnet_b6,
    efficientnet_b7,
    efficientnet_v2_l,
    efficientnet_v2_m,
    efficientnet_v2_s,
)
from .classification.googlenet import GoogLeNet, googlenet
from .classification.mobilenetv2 import mobilenet_v2, MobileNetV2
from .classification.mobilenetv3 import (
    mobilenet_v3_large,
    mobilenet_v3_small,
    MobileNetV3,
)
from .classification.regnet import (
    RegNet,
    regnet_x_1_6gf,
    regnet_x_3_2gf,
    regnet_x_8gf,
    regnet_x_16gf,
    regnet_x_32gf,
    regnet_x_400mf,
    regnet_x_800mf,
    regnet_y_1_6gf,
    regnet_y_3_2gf,
    regnet_y_8gf,
    regnet_y_16gf,
    regnet_y_32gf,
    regnet_y_128gf,
    regnet_y_400mf,
    regnet_y_800mf,
)
from .classification.resnet import (
    ResNet,
    resnet18,
    resnet34,
    resnet50,
    resnet101,
    resnet152,
    resnext50_32x4d,
    resnext101_32x8d,
    wide_resnet50_2,
    wide_resnet101_2,
)
from .classification.shufflenetv2 import (
    shufflenet_v2_x0_5,
    shufflenet_v2_x1_0,
    shufflenet_v2_x1_5,
    shufflenet_v2_x2_0,
    ShuffleNetV2,
)
from .classification.squeezenet import SqueezeNet, squeezenet1_0, squeezenet1_1
from .classification.swin import (
    swin_b,
    swin_s,
    swin_t,
    swin_v2_b,
    swin_v2_s,
    swin_v2_t,
    SwinTransformer,
)
from .classification.vgg import (
    VGG,
    vgg11,
    vgg11_bn,
    vgg13,
    vgg13_bn,
    vgg16,
    vgg16_bn,
    vgg19,
    vgg19_bn,
)
from .classification.vit import (
    _VitAttention,
    _VitBlock,
    VisionTransformer,
    vit_base,
    vit_small,
    vit_tiny,
)
